@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     AccessPreviewStatusReasonCodeType,
@@ -23,10 +23,13 @@ from .literals import (
     FindingChangeTypeType,
     FindingSourceTypeType,
     FindingStatusType,
+    FindingStatusUpdateType,
     JobErrorCodeType,
     JobStatusType,
     KmsGrantOperationType,
+    LocaleType,
     OrderByType,
+    PolicyTypeType,
     ReasonCodeType,
     ResourceTypeType,
     TypeType,
@@ -48,13 +51,20 @@ __all__ = (
     "AnalyzedResourceSummaryTypeDef",
     "AnalyzedResourceTypeDef",
     "AnalyzerSummaryTypeDef",
+    "ApplyArchiveRuleRequestTypeDef",
     "ArchiveRuleSummaryTypeDef",
+    "CancelPolicyGenerationRequestTypeDef",
     "CloudTrailDetailsTypeDef",
     "CloudTrailPropertiesTypeDef",
     "ConfigurationTypeDef",
-    "CreateAccessPreviewResponseTypeDef",
-    "CreateAnalyzerResponseTypeDef",
+    "CreateAccessPreviewRequestTypeDef",
+    "CreateAccessPreviewResponseResponseTypeDef",
+    "CreateAnalyzerRequestTypeDef",
+    "CreateAnalyzerResponseResponseTypeDef",
+    "CreateArchiveRuleRequestTypeDef",
     "CriterionTypeDef",
+    "DeleteAnalyzerRequestTypeDef",
+    "DeleteArchiveRuleRequestTypeDef",
     "FindingSourceDetailTypeDef",
     "FindingSourceTypeDef",
     "FindingSummaryTypeDef",
@@ -62,12 +72,18 @@ __all__ = (
     "GeneratedPolicyPropertiesTypeDef",
     "GeneratedPolicyResultTypeDef",
     "GeneratedPolicyTypeDef",
-    "GetAccessPreviewResponseTypeDef",
-    "GetAnalyzedResourceResponseTypeDef",
-    "GetAnalyzerResponseTypeDef",
-    "GetArchiveRuleResponseTypeDef",
-    "GetFindingResponseTypeDef",
-    "GetGeneratedPolicyResponseTypeDef",
+    "GetAccessPreviewRequestTypeDef",
+    "GetAccessPreviewResponseResponseTypeDef",
+    "GetAnalyzedResourceRequestTypeDef",
+    "GetAnalyzedResourceResponseResponseTypeDef",
+    "GetAnalyzerRequestTypeDef",
+    "GetAnalyzerResponseResponseTypeDef",
+    "GetArchiveRuleRequestTypeDef",
+    "GetArchiveRuleResponseResponseTypeDef",
+    "GetFindingRequestTypeDef",
+    "GetFindingResponseResponseTypeDef",
+    "GetGeneratedPolicyRequestTypeDef",
+    "GetGeneratedPolicyResponseResponseTypeDef",
     "IamRoleConfigurationTypeDef",
     "InlineArchiveRuleTypeDef",
     "JobDetailsTypeDef",
@@ -75,14 +91,22 @@ __all__ = (
     "KmsGrantConfigurationTypeDef",
     "KmsGrantConstraintsTypeDef",
     "KmsKeyConfigurationTypeDef",
-    "ListAccessPreviewFindingsResponseTypeDef",
-    "ListAccessPreviewsResponseTypeDef",
-    "ListAnalyzedResourcesResponseTypeDef",
-    "ListAnalyzersResponseTypeDef",
-    "ListArchiveRulesResponseTypeDef",
-    "ListFindingsResponseTypeDef",
-    "ListPolicyGenerationsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListAccessPreviewFindingsRequestTypeDef",
+    "ListAccessPreviewFindingsResponseResponseTypeDef",
+    "ListAccessPreviewsRequestTypeDef",
+    "ListAccessPreviewsResponseResponseTypeDef",
+    "ListAnalyzedResourcesRequestTypeDef",
+    "ListAnalyzedResourcesResponseResponseTypeDef",
+    "ListAnalyzersRequestTypeDef",
+    "ListAnalyzersResponseResponseTypeDef",
+    "ListArchiveRulesRequestTypeDef",
+    "ListArchiveRulesResponseResponseTypeDef",
+    "ListFindingsRequestTypeDef",
+    "ListFindingsResponseResponseTypeDef",
+    "ListPolicyGenerationsRequestTypeDef",
+    "ListPolicyGenerationsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "LocationTypeDef",
     "NetworkOriginConfigurationTypeDef",
     "PaginatorConfigTypeDef",
@@ -90,6 +114,7 @@ __all__ = (
     "PolicyGenerationDetailsTypeDef",
     "PolicyGenerationTypeDef",
     "PositionTypeDef",
+    "ResponseMetadataTypeDef",
     "S3AccessPointConfigurationTypeDef",
     "S3BucketAclGrantConfigurationTypeDef",
     "S3BucketConfigurationTypeDef",
@@ -98,13 +123,20 @@ __all__ = (
     "SortCriteriaTypeDef",
     "SpanTypeDef",
     "SqsQueueConfigurationTypeDef",
-    "StartPolicyGenerationResponseTypeDef",
+    "StartPolicyGenerationRequestTypeDef",
+    "StartPolicyGenerationResponseResponseTypeDef",
+    "StartResourceScanRequestTypeDef",
     "StatusReasonTypeDef",
     "SubstringTypeDef",
+    "TagResourceRequestTypeDef",
     "TrailPropertiesTypeDef",
     "TrailTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateArchiveRuleRequestTypeDef",
+    "UpdateFindingsRequestTypeDef",
     "ValidatePolicyFindingTypeDef",
-    "ValidatePolicyResponseTypeDef",
+    "ValidatePolicyRequestTypeDef",
+    "ValidatePolicyResponseResponseTypeDef",
     "VpcConfigurationTypeDef",
 )
 
@@ -268,6 +300,28 @@ class AnalyzerSummaryTypeDef(_RequiredAnalyzerSummaryTypeDef, _OptionalAnalyzerS
     pass
 
 
+_RequiredApplyArchiveRuleRequestTypeDef = TypedDict(
+    "_RequiredApplyArchiveRuleRequestTypeDef",
+    {
+        "analyzerArn": str,
+        "ruleName": str,
+    },
+)
+_OptionalApplyArchiveRuleRequestTypeDef = TypedDict(
+    "_OptionalApplyArchiveRuleRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class ApplyArchiveRuleRequestTypeDef(
+    _RequiredApplyArchiveRuleRequestTypeDef, _OptionalApplyArchiveRuleRequestTypeDef
+):
+    pass
+
+
 ArchiveRuleSummaryTypeDef = TypedDict(
     "ArchiveRuleSummaryTypeDef",
     {
@@ -278,18 +332,25 @@ ArchiveRuleSummaryTypeDef = TypedDict(
     },
 )
 
+CancelPolicyGenerationRequestTypeDef = TypedDict(
+    "CancelPolicyGenerationRequestTypeDef",
+    {
+        "jobId": str,
+    },
+)
+
 _RequiredCloudTrailDetailsTypeDef = TypedDict(
     "_RequiredCloudTrailDetailsTypeDef",
     {
         "accessRole": str,
-        "startTime": datetime,
+        "startTime": Union[datetime, str],
         "trails": List["TrailTypeDef"],
     },
 )
 _OptionalCloudTrailDetailsTypeDef = TypedDict(
     "_OptionalCloudTrailDetailsTypeDef",
     {
-        "endTime": datetime,
+        "endTime": Union[datetime, str],
     },
     total=False,
 )
@@ -322,21 +383,91 @@ ConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-CreateAccessPreviewResponseTypeDef = TypedDict(
-    "CreateAccessPreviewResponseTypeDef",
+_RequiredCreateAccessPreviewRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessPreviewRequestTypeDef",
     {
-        "id": str,
+        "analyzerArn": str,
+        "configurations": Dict[str, "ConfigurationTypeDef"],
     },
 )
-
-CreateAnalyzerResponseTypeDef = TypedDict(
-    "CreateAnalyzerResponseTypeDef",
+_OptionalCreateAccessPreviewRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessPreviewRequestTypeDef",
     {
-        "arn": str,
+        "clientToken": str,
     },
     total=False,
 )
 
+
+class CreateAccessPreviewRequestTypeDef(
+    _RequiredCreateAccessPreviewRequestTypeDef, _OptionalCreateAccessPreviewRequestTypeDef
+):
+    pass
+
+
+CreateAccessPreviewResponseResponseTypeDef = TypedDict(
+    "CreateAccessPreviewResponseResponseTypeDef",
+    {
+        "id": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateAnalyzerRequestTypeDef = TypedDict(
+    "_RequiredCreateAnalyzerRequestTypeDef",
+    {
+        "analyzerName": str,
+        "type": TypeType,
+    },
+)
+_OptionalCreateAnalyzerRequestTypeDef = TypedDict(
+    "_OptionalCreateAnalyzerRequestTypeDef",
+    {
+        "archiveRules": List["InlineArchiveRuleTypeDef"],
+        "clientToken": str,
+        "tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class CreateAnalyzerRequestTypeDef(
+    _RequiredCreateAnalyzerRequestTypeDef, _OptionalCreateAnalyzerRequestTypeDef
+):
+    pass
+
+
+CreateAnalyzerResponseResponseTypeDef = TypedDict(
+    "CreateAnalyzerResponseResponseTypeDef",
+    {
+        "arn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateArchiveRuleRequestTypeDef = TypedDict(
+    "_RequiredCreateArchiveRuleRequestTypeDef",
+    {
+        "analyzerName": str,
+        "filter": Dict[str, "CriterionTypeDef"],
+        "ruleName": str,
+    },
+)
+_OptionalCreateArchiveRuleRequestTypeDef = TypedDict(
+    "_OptionalCreateArchiveRuleRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class CreateArchiveRuleRequestTypeDef(
+    _RequiredCreateArchiveRuleRequestTypeDef, _OptionalCreateArchiveRuleRequestTypeDef
+):
+    pass
+
+
 CriterionTypeDef = TypedDict(
     "CriterionTypeDef",
     {
@@ -348,6 +479,49 @@ CriterionTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredDeleteAnalyzerRequestTypeDef = TypedDict(
+    "_RequiredDeleteAnalyzerRequestTypeDef",
+    {
+        "analyzerName": str,
+    },
+)
+_OptionalDeleteAnalyzerRequestTypeDef = TypedDict(
+    "_OptionalDeleteAnalyzerRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteAnalyzerRequestTypeDef(
+    _RequiredDeleteAnalyzerRequestTypeDef, _OptionalDeleteAnalyzerRequestTypeDef
+):
+    pass
+
+
+_RequiredDeleteArchiveRuleRequestTypeDef = TypedDict(
+    "_RequiredDeleteArchiveRuleRequestTypeDef",
+    {
+        "analyzerName": str,
+        "ruleName": str,
+    },
+)
+_OptionalDeleteArchiveRuleRequestTypeDef = TypedDict(
+    "_OptionalDeleteArchiveRuleRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class DeleteArchiveRuleRequestTypeDef(
+    _RequiredDeleteArchiveRuleRequestTypeDef, _OptionalDeleteArchiveRuleRequestTypeDef
+):
+    pass
+
+
 FindingSourceDetailTypeDef = TypedDict(
     "FindingSourceDetailTypeDef",
     {
@@ -487,48 +661,113 @@ GeneratedPolicyTypeDef = TypedDict(
     },
 )
 
-GetAccessPreviewResponseTypeDef = TypedDict(
-    "GetAccessPreviewResponseTypeDef",
+GetAccessPreviewRequestTypeDef = TypedDict(
+    "GetAccessPreviewRequestTypeDef",
+    {
+        "accessPreviewId": str,
+        "analyzerArn": str,
+    },
+)
+
+GetAccessPreviewResponseResponseTypeDef = TypedDict(
+    "GetAccessPreviewResponseResponseTypeDef",
     {
         "accessPreview": "AccessPreviewTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetAnalyzedResourceResponseTypeDef = TypedDict(
-    "GetAnalyzedResourceResponseTypeDef",
+GetAnalyzedResourceRequestTypeDef = TypedDict(
+    "GetAnalyzedResourceRequestTypeDef",
+    {
+        "analyzerArn": str,
+        "resourceArn": str,
+    },
+)
+
+GetAnalyzedResourceResponseResponseTypeDef = TypedDict(
+    "GetAnalyzedResourceResponseResponseTypeDef",
     {
         "resource": "AnalyzedResourceTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-GetAnalyzerResponseTypeDef = TypedDict(
-    "GetAnalyzerResponseTypeDef",
+GetAnalyzerRequestTypeDef = TypedDict(
+    "GetAnalyzerRequestTypeDef",
+    {
+        "analyzerName": str,
+    },
+)
+
+GetAnalyzerResponseResponseTypeDef = TypedDict(
+    "GetAnalyzerResponseResponseTypeDef",
     {
         "analyzer": "AnalyzerSummaryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetArchiveRuleResponseTypeDef = TypedDict(
-    "GetArchiveRuleResponseTypeDef",
+GetArchiveRuleRequestTypeDef = TypedDict(
+    "GetArchiveRuleRequestTypeDef",
+    {
+        "analyzerName": str,
+        "ruleName": str,
+    },
+)
+
+GetArchiveRuleResponseResponseTypeDef = TypedDict(
+    "GetArchiveRuleResponseResponseTypeDef",
     {
         "archiveRule": "ArchiveRuleSummaryTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetFindingResponseTypeDef = TypedDict(
-    "GetFindingResponseTypeDef",
+GetFindingRequestTypeDef = TypedDict(
+    "GetFindingRequestTypeDef",
+    {
+        "analyzerArn": str,
+        "id": str,
+    },
+)
+
+GetFindingResponseResponseTypeDef = TypedDict(
+    "GetFindingResponseResponseTypeDef",
     {
         "finding": "FindingTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredGetGeneratedPolicyRequestTypeDef = TypedDict(
+    "_RequiredGetGeneratedPolicyRequestTypeDef",
+    {
+        "jobId": str,
+    },
+)
+_OptionalGetGeneratedPolicyRequestTypeDef = TypedDict(
+    "_OptionalGetGeneratedPolicyRequestTypeDef",
+    {
+        "includeResourcePlaceholders": bool,
+        "includeServiceLevelTemplate": bool,
     },
     total=False,
 )
 
-GetGeneratedPolicyResponseTypeDef = TypedDict(
-    "GetGeneratedPolicyResponseTypeDef",
+
+class GetGeneratedPolicyRequestTypeDef(
+    _RequiredGetGeneratedPolicyRequestTypeDef, _OptionalGetGeneratedPolicyRequestTypeDef
+):
+    pass
+
+
+GetGeneratedPolicyResponseResponseTypeDef = TypedDict(
+    "GetGeneratedPolicyResponseResponseTypeDef",
     {
         "generatedPolicyResult": "GeneratedPolicyResultTypeDef",
         "jobDetails": "JobDetailsTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
@@ -620,160 +859,218 @@ KmsKeyConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListAccessPreviewFindingsResponseTypeDef = TypedDict(
-    "_RequiredListAccessPreviewFindingsResponseTypeDef",
+_RequiredListAccessPreviewFindingsRequestTypeDef = TypedDict(
+    "_RequiredListAccessPreviewFindingsRequestTypeDef",
+    {
+        "accessPreviewId": str,
+        "analyzerArn": str,
+    },
+)
+_OptionalListAccessPreviewFindingsRequestTypeDef = TypedDict(
+    "_OptionalListAccessPreviewFindingsRequestTypeDef",
+    {
+        "filter": Dict[str, "CriterionTypeDef"],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+
+class ListAccessPreviewFindingsRequestTypeDef(
+    _RequiredListAccessPreviewFindingsRequestTypeDef,
+    _OptionalListAccessPreviewFindingsRequestTypeDef,
+):
+    pass
+
+
+ListAccessPreviewFindingsResponseResponseTypeDef = TypedDict(
+    "ListAccessPreviewFindingsResponseResponseTypeDef",
     {
         "findings": List["AccessPreviewFindingTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListAccessPreviewFindingsResponseTypeDef = TypedDict(
-    "_OptionalListAccessPreviewFindingsResponseTypeDef",
+
+_RequiredListAccessPreviewsRequestTypeDef = TypedDict(
+    "_RequiredListAccessPreviewsRequestTypeDef",
     {
+        "analyzerArn": str,
+    },
+)
+_OptionalListAccessPreviewsRequestTypeDef = TypedDict(
+    "_OptionalListAccessPreviewsRequestTypeDef",
+    {
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
 
-class ListAccessPreviewFindingsResponseTypeDef(
-    _RequiredListAccessPreviewFindingsResponseTypeDef,
-    _OptionalListAccessPreviewFindingsResponseTypeDef,
+class ListAccessPreviewsRequestTypeDef(
+    _RequiredListAccessPreviewsRequestTypeDef, _OptionalListAccessPreviewsRequestTypeDef
 ):
     pass
 
 
-_RequiredListAccessPreviewsResponseTypeDef = TypedDict(
-    "_RequiredListAccessPreviewsResponseTypeDef",
+ListAccessPreviewsResponseResponseTypeDef = TypedDict(
+    "ListAccessPreviewsResponseResponseTypeDef",
     {
         "accessPreviews": List["AccessPreviewSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListAccessPreviewsResponseTypeDef = TypedDict(
-    "_OptionalListAccessPreviewsResponseTypeDef",
+
+_RequiredListAnalyzedResourcesRequestTypeDef = TypedDict(
+    "_RequiredListAnalyzedResourcesRequestTypeDef",
     {
+        "analyzerArn": str,
+    },
+)
+_OptionalListAnalyzedResourcesRequestTypeDef = TypedDict(
+    "_OptionalListAnalyzedResourcesRequestTypeDef",
+    {
+        "maxResults": int,
         "nextToken": str,
+        "resourceType": ResourceTypeType,
     },
     total=False,
 )
 
 
-class ListAccessPreviewsResponseTypeDef(
-    _RequiredListAccessPreviewsResponseTypeDef, _OptionalListAccessPreviewsResponseTypeDef
+class ListAnalyzedResourcesRequestTypeDef(
+    _RequiredListAnalyzedResourcesRequestTypeDef, _OptionalListAnalyzedResourcesRequestTypeDef
 ):
     pass
 
 
-_RequiredListAnalyzedResourcesResponseTypeDef = TypedDict(
-    "_RequiredListAnalyzedResourcesResponseTypeDef",
+ListAnalyzedResourcesResponseResponseTypeDef = TypedDict(
+    "ListAnalyzedResourcesResponseResponseTypeDef",
     {
         "analyzedResources": List["AnalyzedResourceSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListAnalyzedResourcesResponseTypeDef = TypedDict(
-    "_OptionalListAnalyzedResourcesResponseTypeDef",
+
+ListAnalyzersRequestTypeDef = TypedDict(
+    "ListAnalyzersRequestTypeDef",
     {
+        "maxResults": int,
         "nextToken": str,
+        "type": TypeType,
     },
     total=False,
 )
 
-
-class ListAnalyzedResourcesResponseTypeDef(
-    _RequiredListAnalyzedResourcesResponseTypeDef, _OptionalListAnalyzedResourcesResponseTypeDef
-):
-    pass
-
-
-_RequiredListAnalyzersResponseTypeDef = TypedDict(
-    "_RequiredListAnalyzersResponseTypeDef",
+ListAnalyzersResponseResponseTypeDef = TypedDict(
+    "ListAnalyzersResponseResponseTypeDef",
     {
         "analyzers": List["AnalyzerSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListAnalyzersResponseTypeDef = TypedDict(
-    "_OptionalListAnalyzersResponseTypeDef",
+
+_RequiredListArchiveRulesRequestTypeDef = TypedDict(
+    "_RequiredListArchiveRulesRequestTypeDef",
     {
+        "analyzerName": str,
+    },
+)
+_OptionalListArchiveRulesRequestTypeDef = TypedDict(
+    "_OptionalListArchiveRulesRequestTypeDef",
+    {
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
 
-class ListAnalyzersResponseTypeDef(
-    _RequiredListAnalyzersResponseTypeDef, _OptionalListAnalyzersResponseTypeDef
+class ListArchiveRulesRequestTypeDef(
+    _RequiredListArchiveRulesRequestTypeDef, _OptionalListArchiveRulesRequestTypeDef
 ):
     pass
 
 
-_RequiredListArchiveRulesResponseTypeDef = TypedDict(
-    "_RequiredListArchiveRulesResponseTypeDef",
+ListArchiveRulesResponseResponseTypeDef = TypedDict(
+    "ListArchiveRulesResponseResponseTypeDef",
     {
         "archiveRules": List["ArchiveRuleSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListArchiveRulesResponseTypeDef = TypedDict(
-    "_OptionalListArchiveRulesResponseTypeDef",
+
+_RequiredListFindingsRequestTypeDef = TypedDict(
+    "_RequiredListFindingsRequestTypeDef",
     {
+        "analyzerArn": str,
+    },
+)
+_OptionalListFindingsRequestTypeDef = TypedDict(
+    "_OptionalListFindingsRequestTypeDef",
+    {
+        "filter": Dict[str, "CriterionTypeDef"],
+        "maxResults": int,
         "nextToken": str,
+        "sort": "SortCriteriaTypeDef",
     },
     total=False,
 )
 
 
-class ListArchiveRulesResponseTypeDef(
-    _RequiredListArchiveRulesResponseTypeDef, _OptionalListArchiveRulesResponseTypeDef
+class ListFindingsRequestTypeDef(
+    _RequiredListFindingsRequestTypeDef, _OptionalListFindingsRequestTypeDef
 ):
     pass
 
 
-_RequiredListFindingsResponseTypeDef = TypedDict(
-    "_RequiredListFindingsResponseTypeDef",
+ListFindingsResponseResponseTypeDef = TypedDict(
+    "ListFindingsResponseResponseTypeDef",
     {
         "findings": List["FindingSummaryTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListFindingsResponseTypeDef = TypedDict(
-    "_OptionalListFindingsResponseTypeDef",
+
+ListPolicyGenerationsRequestTypeDef = TypedDict(
+    "ListPolicyGenerationsRequestTypeDef",
     {
+        "maxResults": int,
         "nextToken": str,
+        "principalArn": str,
     },
     total=False,
 )
 
-
-class ListFindingsResponseTypeDef(
-    _RequiredListFindingsResponseTypeDef, _OptionalListFindingsResponseTypeDef
-):
-    pass
-
-
-_RequiredListPolicyGenerationsResponseTypeDef = TypedDict(
-    "_RequiredListPolicyGenerationsResponseTypeDef",
+ListPolicyGenerationsResponseResponseTypeDef = TypedDict(
+    "ListPolicyGenerationsResponseResponseTypeDef",
     {
+        "nextToken": str,
         "policyGenerations": List["PolicyGenerationTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
-_OptionalListPolicyGenerationsResponseTypeDef = TypedDict(
-    "_OptionalListPolicyGenerationsResponseTypeDef",
+
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
     {
-        "nextToken": str,
+        "resourceArn": str,
     },
-    total=False,
 )
 
-
-class ListPolicyGenerationsResponseTypeDef(
-    _RequiredListPolicyGenerationsResponseTypeDef, _OptionalListPolicyGenerationsResponseTypeDef
-):
-    pass
-
-
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 LocationTypeDef = TypedDict(
@@ -852,6 +1149,17 @@ PositionTypeDef = TypedDict(
     },
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 S3AccessPointConfigurationTypeDef = TypedDict(
     "S3AccessPointConfigurationTypeDef",
     {
@@ -923,10 +1231,41 @@ SqsQueueConfigurationTypeDef = TypedDict(
     total=False,
 )
 
-StartPolicyGenerationResponseTypeDef = TypedDict(
-    "StartPolicyGenerationResponseTypeDef",
+_RequiredStartPolicyGenerationRequestTypeDef = TypedDict(
+    "_RequiredStartPolicyGenerationRequestTypeDef",
+    {
+        "policyGenerationDetails": "PolicyGenerationDetailsTypeDef",
+    },
+)
+_OptionalStartPolicyGenerationRequestTypeDef = TypedDict(
+    "_OptionalStartPolicyGenerationRequestTypeDef",
+    {
+        "clientToken": str,
+        "cloudTrailDetails": "CloudTrailDetailsTypeDef",
+    },
+    total=False,
+)
+
+
+class StartPolicyGenerationRequestTypeDef(
+    _RequiredStartPolicyGenerationRequestTypeDef, _OptionalStartPolicyGenerationRequestTypeDef
+):
+    pass
+
+
+StartPolicyGenerationResponseResponseTypeDef = TypedDict(
+    "StartPolicyGenerationResponseResponseTypeDef",
     {
         "jobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StartResourceScanRequestTypeDef = TypedDict(
+    "StartResourceScanRequestTypeDef",
+    {
+        "analyzerArn": str,
+        "resourceArn": str,
     },
 )
 
@@ -945,6 +1284,14 @@ SubstringTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tags": Dict[str, str],
+    },
+)
+
 _RequiredTrailPropertiesTypeDef = TypedDict(
     "_RequiredTrailPropertiesTypeDef",
     {
@@ -985,6 +1332,61 @@ class TrailTypeDef(_RequiredTrailTypeDef, _OptionalTrailTypeDef):
     pass
 
 
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "resourceArn": str,
+        "tagKeys": List[str],
+    },
+)
+
+_RequiredUpdateArchiveRuleRequestTypeDef = TypedDict(
+    "_RequiredUpdateArchiveRuleRequestTypeDef",
+    {
+        "analyzerName": str,
+        "filter": Dict[str, "CriterionTypeDef"],
+        "ruleName": str,
+    },
+)
+_OptionalUpdateArchiveRuleRequestTypeDef = TypedDict(
+    "_OptionalUpdateArchiveRuleRequestTypeDef",
+    {
+        "clientToken": str,
+    },
+    total=False,
+)
+
+
+class UpdateArchiveRuleRequestTypeDef(
+    _RequiredUpdateArchiveRuleRequestTypeDef, _OptionalUpdateArchiveRuleRequestTypeDef
+):
+    pass
+
+
+_RequiredUpdateFindingsRequestTypeDef = TypedDict(
+    "_RequiredUpdateFindingsRequestTypeDef",
+    {
+        "analyzerArn": str,
+        "status": FindingStatusUpdateType,
+    },
+)
+_OptionalUpdateFindingsRequestTypeDef = TypedDict(
+    "_OptionalUpdateFindingsRequestTypeDef",
+    {
+        "clientToken": str,
+        "ids": List[str],
+        "resourceArn": str,
+    },
+    total=False,
+)
+
+
+class UpdateFindingsRequestTypeDef(
+    _RequiredUpdateFindingsRequestTypeDef, _OptionalUpdateFindingsRequestTypeDef
+):
+    pass
+
+
 ValidatePolicyFindingTypeDef = TypedDict(
     "ValidatePolicyFindingTypeDef",
     {
@@ -996,27 +1398,39 @@ ValidatePolicyFindingTypeDef = TypedDict(
     },
 )
 
-_RequiredValidatePolicyResponseTypeDef = TypedDict(
-    "_RequiredValidatePolicyResponseTypeDef",
+_RequiredValidatePolicyRequestTypeDef = TypedDict(
+    "_RequiredValidatePolicyRequestTypeDef",
     {
-        "findings": List["ValidatePolicyFindingTypeDef"],
+        "policyDocument": str,
+        "policyType": PolicyTypeType,
     },
 )
-_OptionalValidatePolicyResponseTypeDef = TypedDict(
-    "_OptionalValidatePolicyResponseTypeDef",
+_OptionalValidatePolicyRequestTypeDef = TypedDict(
+    "_OptionalValidatePolicyRequestTypeDef",
     {
+        "locale": LocaleType,
+        "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
 
-class ValidatePolicyResponseTypeDef(
-    _RequiredValidatePolicyResponseTypeDef, _OptionalValidatePolicyResponseTypeDef
+class ValidatePolicyRequestTypeDef(
+    _RequiredValidatePolicyRequestTypeDef, _OptionalValidatePolicyRequestTypeDef
 ):
     pass
 
 
+ValidatePolicyResponseResponseTypeDef = TypedDict(
+    "ValidatePolicyResponseResponseTypeDef",
+    {
+        "findings": List["ValidatePolicyFindingTypeDef"],
+        "nextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 VpcConfigurationTypeDef = TypedDict(
     "VpcConfigurationTypeDef",
     {
